/*global $ WebSocket DataBinder SystemAlarmNotifier*/
function getAcuairPanelData(settings){

    settings = settings || {};
    settings.address = "ws://"+settings.address+"/ws/";
    settings.dataValAttrName = settings.dataValAttrName || "";
    settings.statusElem = settings.statusElem || "";

    var acuairWS = new WebSocket(settings.address);
    var acuairDataBinder = new DataBinder(settings.dataValAttrName);
    var acuairRequestData = {
        type: "read",
        values: [
            {
                name:"status",
                address:"3:0:0:0:1",
                type:"modeLanguage"
            },
            {
                name:"mode",
                address:"3:1:0:0:1",
                type:"modeLanguage"
            },
            {
                name:"actual",
                address: "2:60:0:0:1"
            },
            {
                name:"setpoint",
                address: "2:61:0:0:1"
            }
        ]

    };

    acuairWS.onopen = function() {
        acuairWS.send(JSON.stringify(acuairRequestData));
    };

    acuairWS.onmessage = function (evt) {
        var data = JSON.parse(evt.data);
        switch (data.type) {
            case "valueUpdate":
                acuairDataBinder.insertValues(data.values);
                break;
            case "writeSuccess":
                console.info("Write success", data.values);
                break;
            case "writeError":
                console.error("The following values could not be written", data.values);
                break;
            default:
                console.error("Unrecognized websocket response ", data.type);
        }
    };

    $(document).ready(function() {
        var acuairAlarms = new SystemAlarmNotifier({
            warningAddress: "3:5:0:0:1",
            shutdownAddress: "3:4:0:0:1",
            wsAddress: settings.address,
            element: settings.statusElem,
            onWarning: function() {
                $(settings.statusElem).removeClass("status-shutdown status-normal").addClass("status-warning");
            },
            onShutdown: function() {
                $(settings.statusElem).removeClass("status-warning status-normal").addClass("status-shutdown");
            },
            onOK: function() {
                $(settings.statusElem).removeClass("status-shutdown status-warning").addClass("status-normal");
            }

        });
        acuairAlarms.watchForAlarms();
    });
}



function getCompressorPanelData(settings) {
    settings = settings || {};
    settings.address = "ws://"+settings.address+"/ws/";
    settings.dataValAttrName = settings.dataValAttrName || "";
    settings.statusElem = settings.statusElem || "";

     var compressorWS = new WebSocket(settings.address);
     var compressorDataBinder = new DataBinder(settings.dataValAttrName);
     var compressorRequestData = {
         type: "read",
         values: [
             {
                 name:"status",
                 address:"3:70:0:0:1",
                 type:"modeLanguage"
             },
             {
                 name:"suction",
                 address: "0:2:0:0:1"
             },
             {
                 name:"discharge",
                 address: "0:3:0:0:1"
             },
             {
                 name:"oil",
                 address: "0:4:0:0:1"
             },
             {
                 name:"control-value",
                 address: "2:60:0:0:1"
             }
         ]


     };

     compressorWS.onopen = function() {
         compressorWS.send(JSON.stringify(compressorRequestData));
     };

     compressorWS.onmessage = function (evt) {
         var data = JSON.parse(evt.data);
         switch (data.type) {
             case "valueUpdate":
                 compressorDataBinder.insertValues(data.values);
                 break;
             case "writeSuccess":
                 console.info("Write success", data.values);
                 break;
             case "writeError":
                 console.error("The following values could not be written", data.values);
                 break;
             default:
                 console.error("Unrecognized websocket response ", data.type);
         }


     };

     $(document).ready(function() {
             var compressorAlarms = new SystemAlarmNotifier({
                 warningAddress: "3:5:0:0:1",
                 shutdownAddress: "3:4:0:0:1",
                 wsAddress: settings.address,
                 element: settings.statusElem,
                 onWarning: function() {
                     $(settings.statusElem).removeClass("status-shutdown status-normal").addClass("status-warning");
                 },
                 onShutdown: function() {
                     $(settings.statusElem).removeClass("status-warning status-normal").addClass("status-shutdown");
                 },
                 onOK: function() {
                     $(settings.statusElem).removeClass("status-shutdown status-warning").addClass("status-normal");
                 }
                 
             });
         compressorAlarms.watchForAlarms();
     });
    
}

